==> eclipse_2.1.3.orig.tar.gz: plugins/org.eclipse.pde.core/src/org/eclipse/pde/core/plugin/IPluginModelBase.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.core.plugin;

import org.eclipse.pde.core.*;
import org.eclipse.pde.core.build.IBuildModel;
/**
 * This type of model is created by parsing the manifest file.
 * It serves as a base interface for both plug-in and
 * fragment models by holding data common to both.
 * If the file is a workspace resource, it will be
 * available as the underlying resource of the model.
 * The model may be read-only or editable.
 * It will also make a reference to the build.properties
 * model when created. The reference will be of the
 * same type as the model itself: if the model is
 * editable, it will attempt to obtain an exclusive
 * editable copy of build.properties model.
 * <p>
 * The plug-in model can be disabled. Disabling the
 * model will not change its data. Users of the
 * model will have to decide if the disabled state
 * if of any importance to them or not.
 * <p>
 * The model is capable of notifying listeners
 * about changes. An attempt to change a read-only
 * model will result in a CoreException.
 * <p>
 * <b>Note:</b> This interface is part of an interim API that is still under development and expected to
 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
 * (repeatedly) as the API evolves.
 * </p>
 */
public interface IPluginModelBase extends IModel, IModelChangeProvider {
	/**
	 * @return org.eclipse.pde.ui.model.plugin.IPluginBase
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	IPluginBase createPluginBase();
	/**
	 * Returns an associated build.properties model
	 * that works in conjunction with this model.
	 *
	 * @return the matching plugin.jars model
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	IBuildModel getBuildModel();
	/**
	 * Returns a factory object that should be used
	 * to create new instances of the model objects.
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	IPluginModelFactory getFactory();
	/**
	 * Returns a location of the file that was used
	 * to create this model. This property is used
	 * only for external models.
	 *
	 * @return a location of the external model, or
	 * <samp>null</samp> if the model is created
	 * from a resource.
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	public String getInstallLocation();
	/**
	 * Returns a top-level model object. Equivalent to
	 * calling <pre>getPluginBase(true)</pre>.
	 * @return a top-level model object representing a plug-in or a fragment.
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	IPluginBase getPluginBase();
	/**
	 * Returns a top-level model object.
	 * @param createIfMissing if true, root model object will
	 * be created if not defined.
	 * @return a top-level model object
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	IPluginBase getPluginBase(boolean createIfMissing);
	/**
	 * Returns </samp>true</samp> if this model is currently enabled.
	 *
	 *@return true if the model is enabled
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	public boolean isEnabled();
	/**
	 * @return boolean
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	boolean isFragmentModel();
	/**
	 * Sets the enable state of the model.
	 *
	 * @param enabled the new enable state
	 * <p>
	 * <b>Note:</b> This method is part of an interim API that is still under development and expected to
	 * change significantly before reaching stability. It is being made available at this early stage to solicit feedback
	 * from pioneering adopters on the understanding that any code that uses this API will almost certainly be broken
	 * (repeatedly) as the API evolves.
	 * </p>
	 */
	public void setEnabled(boolean enabled);
}

==> eclipse_3.1.2.orig.tar.gz: plugins/org.eclipse.pde.core/src/org/eclipse/pde/core/plugin/IPluginModelBase.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.core.plugin;

import java.net.*;

import org.eclipse.osgi.service.resolver.*;
import org.eclipse.pde.core.*;
import org.eclipse.pde.core.build.*;
/**
 * This type of model is created by parsing the manifest file.
 * It serves as a base interface for both plug-in and
 * fragment models by holding data common to both.
 * If the file is a workspace resource, it will be
 * available as the underlying resource of the model.
 * The model may be read-only or editable.
 * It will also make a reference to the build.properties
 * model when created. The reference will be of the
 * same type as the model itself: if the model is
 * editable, it will attempt to obtain an exclusive
 * editable copy of build.properties model.
 * <p>
 * The plug-in model can be disabled. Disabling the
 * model will not change its data. Users of the
 * model will have to decide if the disabled state
 * if of any importance to them or not.
 * <p>
 * The model is capable of notifying listeners
 * about changes. An attempt to change a read-only
 * model will result in a CoreException.
 */
public interface IPluginModelBase extends ISharedExtensionsModel, IModelChangeProvider {
	/**
	 * Creates and return a top-level plugin model object
	 *  
	 * @return a top-level model object representing a plug-in or a fragment.
	 */
	IPluginBase createPluginBase();
	/**
	 * Returns an associated build.properties model
	 * that works in conjunction with this model.
	 *
	 * @return the matching plugin.jars model
	 */
	IBuildModel getBuildModel();
	/**
	 * Returns a top-level model object. Equivalent to
	 * calling <pre>getPluginBase(true)</pre>.
	 * 
	 * @return a top-level model object representing a plug-in or a fragment.
	 */
	IPluginBase getPluginBase();
	/**
	 * Returns a top-level model object.
	 * 
	 * @param createIfMissing if true, root model object will
	 * be created if not defined.
	 * 
	 * @return a top-level model object
	 */
	IPluginBase getPluginBase(boolean createIfMissing);
	/**
	 * Returns </samp>true</samp> if this model is currently enabled.
	 *
	 *@return true if the model is enabled
	 */
	boolean isEnabled();
	/**
	 * Tests if this model is for the plug-in fragment.
	 * 
	 * @return <code>true</code> if the model is for the fragment,
	 * <code>false</code> otherwise.
	 */
	boolean isFragmentModel();
	/**
	 * Sets the enable state of the model.
	 *
	 * @param enabled the new enable state
	 */
	void setEnabled(boolean enabled);
	/**
	 * Returns the factory that can be used to
	 * create new objects for this model
	 * @return the plug-in model factory
	 */
	IPluginModelFactory getPluginFactory();
	/**
	 * Returns the location where property file containing
	 * translations of names in this model can be found.
	 * 
	 * @return the location of the property file with translations
	 */
	URL getNLLookupLocation();
	/**
	 * Returns the bundle description of the plug-in
	 * in case the plug-in uses the new OSGi bundle layout. 
	 * 
	 * @return bundle description if this is an OSGi plug-in,
	 * or <code>null</code> if the plug-in is in a classic
	 * format.
	 * 
	 * @since 3.0
	 */
	BundleDescription getBundleDescription();
	/**
	 * Associates the bundle description of the plug-in
	 * with this model in case the plug-in uses the new
	 * OSGi bundle layout.
	 * 
	 * @param description bundle description to associate
	 * with this model
	 * 
	 * @since 3.0
	 */
	void setBundleDescription(BundleDescription description);
}
